@@ -938,31 +938,31 @@ SAL_DLLPUBLIC_EXPORT OUString const *  getFollowPageWords_ro_RO(sal_Int16& count
 static constexpr OUStringLiteral calendarID0 = u"\x0067\x0072\x0065\x0067\x006f\x0072\x0069\x0061\x006e";
 static constexpr OUStringLiteral defaultCalendar0 = u"\x1";
 static constexpr OUStringLiteral dayID00 = u"\x0073\x0075\x006e";
-static constexpr OUStringLiteral dayDefaultAbbrvName00 = u"\x0044";
+static constexpr OUStringLiteral dayDefaultAbbrvName00 = u"\x0064\x0075\x006d\x002e";
 static constexpr OUStringLiteral dayDefaultFullName00 = u"\x0064\x0075\x006d\x0069\x006e\x0069\x0063\x0103";
 static constexpr OUStringLiteral dayDefaultNarrowName00 = u"\x0064";
 static constexpr OUStringLiteral dayID01 = u"\x006d\x006f\x006e";
-static constexpr OUStringLiteral dayDefaultAbbrvName01 = u"\x004c";
+static constexpr OUStringLiteral dayDefaultAbbrvName01 = u"\x006c\x0075\x006e\x002e";
 static constexpr OUStringLiteral dayDefaultFullName01 = u"\x006c\x0075\x006e\x0069";
 static constexpr OUStringLiteral dayDefaultNarrowName01 = u"\x006c";
 static constexpr OUStringLiteral dayID02 = u"\x0074\x0075\x0065";
-static constexpr OUStringLiteral dayDefaultAbbrvName02 = u"\x004d\x0061";
-static constexpr OUStringLiteral dayDefaultFullName02 = u"\x006d\x0061\x0072\x0163\x0069";
+static constexpr OUStringLiteral dayDefaultAbbrvName02 = u"\x006d\x0061\x0072\x002e";
+static constexpr OUStringLiteral dayDefaultFullName02 = u"\x006d\x0061\x0072\x021b\x0069";
 static constexpr OUStringLiteral dayDefaultNarrowName02 = u"\x006d";
 static constexpr OUStringLiteral dayID03 = u"\x0077\x0065\x0064";
-static constexpr OUStringLiteral dayDefaultAbbrvName03 = u"\x004d\x0069";
+static constexpr OUStringLiteral dayDefaultAbbrvName03 = u"\x006d\x0069\x0065\x002e";
 static constexpr OUStringLiteral dayDefaultFullName03 = u"\x006d\x0069\x0065\x0072\x0063\x0075\x0072\x0069";
 static constexpr OUStringLiteral dayDefaultNarrowName03 = u"\x006d";
 static constexpr OUStringLiteral dayID04 = u"\x0074\x0068\x0075";
-static constexpr OUStringLiteral dayDefaultAbbrvName04 = u"\x004a";
+static constexpr OUStringLiteral dayDefaultAbbrvName04 = u"\x006a\x006f\x0069\x002e";
 static constexpr OUStringLiteral dayDefaultFullName04 = u"\x006a\x006f\x0069";
 static constexpr OUStringLiteral dayDefaultNarrowName04 = u"\x006a";
 static constexpr OUStringLiteral dayID05 = u"\x0066\x0072\x0069";
-static constexpr OUStringLiteral dayDefaultAbbrvName05 = u"\x0056";
+static constexpr OUStringLiteral dayDefaultAbbrvName05 = u"\x0076\x0069\x006e\x002e";
 static constexpr OUStringLiteral dayDefaultFullName05 = u"\x0076\x0069\x006e\x0065\x0072\x0069";
 static constexpr OUStringLiteral dayDefaultNarrowName05 = u"\x0076";
 static constexpr OUStringLiteral dayID06 = u"\x0073\x0061\x0074";
-static constexpr OUStringLiteral dayDefaultAbbrvName06 = u"\x0053";
+static constexpr OUStringLiteral dayDefaultAbbrvName06 = u"\x0073\x00e2\x006d\x002e";
 static constexpr OUStringLiteral dayDefaultFullName06 = u"\x0073\x00e2\x006d\x0062\x0103\x0074\x0103";
 static constexpr OUStringLiteral dayDefaultNarrowName06 = u"\x0073";
 static constexpr OUStringLiteral monthID00 = u"\x006a\x0061\x006e";
